@@ -21,7 +21,8 @@ from sklearn.manifold._t_sne import _kl_divergence_bh
 from sklearn.manifold._t_sne import _gradient_descent
 from sklearn.manifold._t_sne import trustworthiness
 from sklearn.manifold import TSNE
-from sklearn.manifold import _barnes_hut_tsne
+# mypy error: Module 'sklearn.manifold' has no attribute '_barnes_hut_tsne'
+from sklearn.manifold import _barnes_hut_tsne  # type: ignore
 from sklearn.manifold._utils import _binary_search_perplexity
 from sklearn.datasets import make_blobs
 from scipy.optimize import check_grad
@@ -772,11 +773,11 @@ def test_uniform_grid(method):
     we re-run t-SNE from the final point when the convergence is not good
     enough.
     """
-    seeds = [0, 1, 2]
+    seeds = range(3)
     n_iter = 500
     for seed in seeds:
         tsne = TSNE(n_components=2, init='random', random_state=seed,
-                    perplexity=20, n_iter=n_iter, method=method)
+                    perplexity=50, n_iter=n_iter, method=method)
         Y = tsne.fit_transform(X_2d_grid)
 
         try_name = "{}_{}".format(method, seed)
